#[repr(i32)]pub enum BasePolicy {
Unspecified = 0,
Allow = 1,
Deny = 2,
AllowIfAdminOrSuperAdmin = 3,
AllowIfSuperAdmin = 4,
}Expand description
Base policy
Variants
Implementations
Sourceimpl BasePolicy
impl BasePolicy
Sourceimpl BasePolicy
impl BasePolicy
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.